@@ -1,5 +1,5 @@
 <?php
-/* unsafe_image_rules -- Version 0.4
+/* unsafe_image_rules -- Version 0.5
  * By Robin Rainton <robin@rainton.com>
  * http://rainton.com/fun/freeware
  *
@@ -7,10 +7,10 @@
  * Shamless snatch of code from filters page - thanks guys ;-)
  */
 
-  define('SM_PATH','../../');
-  require_once(SM_PATH . 'include/validate.php');
-  require_once(SM_PATH . 'functions/page_header.php');
-  require_once(SM_PATH . 'include/load_prefs.php');
+if (!defined('SM_PATH')) define('SM_PATH','../../');
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/page_header.php');
+require_once(SM_PATH . 'include/load_prefs.php');
 
 /*
  * Get globals
