@@ -1,5 +1,5 @@
 <?php
-/* unsafe_image_rules -- Version 0.4
+/* unsafe_image_rules -- Version 0.5
  * By Robin Rainton <robin@rainton.com>
  * http://rainton.com/fun/freeware
  *
@@ -8,7 +8,7 @@
  * message each time.
  */
 
-define('SM_PATH','../../');
+if (!defined('SM_PATH')) define('SM_PATH','../../');
 require_once(SM_PATH . "functions/addressbook.php"); 
 
 /*
